==> openshift-model-machine-5.10.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSpecFluent.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.Taint;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface MachineSpecFluent<A extends io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta getMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta item);
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta item);
  public java.lang.String getProviderID();
  public A withProviderID(java.lang.String providerID);
  public java.lang.Boolean hasProviderID();
  
  /**
   * Method is deprecated. use withProviderID instead.
   */
  @java.lang.Deprecated
  public A withNewProviderID(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildProviderSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec getProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec buildProviderSpec();
  public A withProviderSpec(io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec providerSpec);
  public java.lang.Boolean hasProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> withNewProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> withNewProviderSpecLike(io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec item);
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> editProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> editOrNewProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> editOrNewProviderSpecLike(io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec item);
  public A addToTaints(java.lang.Integer index,io.fabric8.kubernetes.api.model.Taint item);
  public A setToTaints(java.lang.Integer index,io.fabric8.kubernetes.api.model.Taint item);
  public A addToTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A addAllToTaints(java.util.Collection<io.fabric8.kubernetes.api.model.Taint> items);
  public A removeFromTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A removeAllFromTaints(java.util.Collection<io.fabric8.kubernetes.api.model.Taint> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Taint> getTaints();
  public io.fabric8.kubernetes.api.model.Taint getTaint(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Taint getFirstTaint();
  public io.fabric8.kubernetes.api.model.Taint getLastTaint();
  public io.fabric8.kubernetes.api.model.Taint getMatchingTaint(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Taint> predicate);
  public java.lang.Boolean hasMatchingTaint(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Taint> predicate);
  public A withTaints(java.util.List<io.fabric8.kubernetes.api.model.Taint> taints);
  public A withTaints(io.fabric8.kubernetes.api.model.Taint... taints);
  public java.lang.Boolean hasTaints();
  public A addNewTaint(java.lang.String effect,java.lang.String key,java.lang.String timeAdded,java.lang.String value);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface ProviderSpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpecFluent<io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<N>>{
    public N and();
    public N endProviderSpec();
    
  }
  
}

==> openshift-model-machine-5.12.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSpecFluent.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.Taint;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface MachineSpecFluent<A extends io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLifecycleHooks instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machine.v1beta1.LifecycleHooks getLifecycleHooks();
  public io.fabric8.openshift.api.model.machine.v1beta1.LifecycleHooks buildLifecycleHooks();
  public A withLifecycleHooks(io.fabric8.openshift.api.model.machine.v1beta1.LifecycleHooks lifecycleHooks);
  public java.lang.Boolean hasLifecycleHooks();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.LifecycleHooksNested<A> withNewLifecycleHooks();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.LifecycleHooksNested<A> withNewLifecycleHooksLike(io.fabric8.openshift.api.model.machine.v1beta1.LifecycleHooks item);
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.LifecycleHooksNested<A> editLifecycleHooks();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.LifecycleHooksNested<A> editOrNewLifecycleHooks();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.LifecycleHooksNested<A> editOrNewLifecycleHooksLike(io.fabric8.openshift.api.model.machine.v1beta1.LifecycleHooks item);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta getMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta item);
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta item);
  public java.lang.String getProviderID();
  public A withProviderID(java.lang.String providerID);
  public java.lang.Boolean hasProviderID();
  
  /**
   * Method is deprecated. use withProviderID instead.
   */
  @java.lang.Deprecated
  public A withNewProviderID(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildProviderSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec getProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec buildProviderSpec();
  public A withProviderSpec(io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec providerSpec);
  public java.lang.Boolean hasProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> withNewProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> withNewProviderSpecLike(io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec item);
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> editProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> editOrNewProviderSpec();
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<A> editOrNewProviderSpecLike(io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpec item);
  public A addToTaints(java.lang.Integer index,io.fabric8.kubernetes.api.model.Taint item);
  public A setToTaints(java.lang.Integer index,io.fabric8.kubernetes.api.model.Taint item);
  public A addToTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A addAllToTaints(java.util.Collection<io.fabric8.kubernetes.api.model.Taint> items);
  public A removeFromTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A removeAllFromTaints(java.util.Collection<io.fabric8.kubernetes.api.model.Taint> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Taint> getTaints();
  public io.fabric8.kubernetes.api.model.Taint getTaint(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Taint getFirstTaint();
  public io.fabric8.kubernetes.api.model.Taint getLastTaint();
  public io.fabric8.kubernetes.api.model.Taint getMatchingTaint(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Taint> predicate);
  public java.lang.Boolean hasMatchingTaint(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Taint> predicate);
  public A withTaints(java.util.List<io.fabric8.kubernetes.api.model.Taint> taints);
  public A withTaints(io.fabric8.kubernetes.api.model.Taint... taints);
  public java.lang.Boolean hasTaints();
  public A addNewTaint(java.lang.String effect,java.lang.String key,java.lang.String timeAdded,java.lang.String value);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface LifecycleHooksNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.machine.v1beta1.LifecycleHooksFluent<io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.LifecycleHooksNested<N>>{
    public N and();
    public N endLifecycleHooks();
    
  }
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface ProviderSpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.machine.v1beta1.ProviderSpecFluent<io.fabric8.openshift.api.model.machine.v1beta1.MachineSpecFluent.ProviderSpecNested<N>>{
    public N and();
    public N endProviderSpec();
    
  }
  
}
